# guitartuner
python tkinter app to tune guitar. 

## usage

On linux install pyalsaaudio and aubio as:

```
pip install -U pyalsaaudio
pip install -U aubio
```

On systems if alsaaudio is not available you could use pyaudio and aubio:

```
pip install -U pyaudio
pip install -U aubio
```

Then run the program using:

`python3 myguitargui.py`

## screenshot
![alt text](https://github.com/jithesh82/guitartuner/blob/main/screenshot.png)

## demo video
![alt text](https://github.com/jithesh82/guitartuner/blob/main/demo.gif)
